# frozen_string_literal: true

#
# Cookbook:: snu_nginx
# Library:: resource/snu_nginx_app_rhel
#
# Copyright:: 2019, Tyler Technologies
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

require_relative 'snu_nginx_app'

class Chef
  class Resource
    # A custom resource for managing Nginx packages on RHEL platforms.
    class SnuNginxAppRhel < SnuNginxApp
      provides :snu_nginx_app, platform_family: 'rhel'

      # The RHEL packages' versions have ".elX.ngx" appended.
      property :version,
               String,
               coerce: proc { |r, v| "#{v}.el#{r.node['platform_version'].to_i}.ngx" }

      # For the install and upgrade actions:
      #   - Ensure openssl is installed
      #   - Configure the Nginx YUM repo
      #   - Force the package resource to use the Nginx YUM repo
      %i[install upgrade].each do |act|
        action act do
          package %w[openssl yum-plugin-versionlock]

          yum_repository 'nginx' do
            description 'Nginx.org repository'
            baseurl 'https://nginx.org/packages/rhel/$releasever/$basearch/'
            gpgkey 'https://nginx.org/keys/nginx_signing.key'
          end

          super()

          # RHEL 8 adds a `--repo` switch that makes this slightly cleaner, but
          # this variation maintains RHEL 7 support.
          edit_resource! :package, new_resource.package_name do
            options %w[--disablerepo=* --enablerepo=nginx]
          end
        end
      end

      # For the :remove action:
      #   - Remove the YUM repository
      action :remove do
        super()
        yum_repository('nginx') { action :remove }
      end
    end
  end
end
