# frozen_string_literal: true

#
# Cookbook:: snu_nginx
# Library:: resource/snu_nginx_service_systemd
#
# Copyright:: 2019, Tyler Technologies
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

require 'chef/platform/service_helpers'
require_relative 'snu_nginx_service'

class Chef
  class Resource
    # A custom resource for managing Nginx services on Systemd platforms.
    class SnuNginxServiceSystemd < SnuNginxService
      provides :snu_nginx_service do
        Chef::Platform::ServiceHelpers.service_resource_providers.include?(:systemd)
      end

      # Create our own Systemd unit file for Nginx. It should (always?) come
      # packaged with one, but this should help guard against a packaged one
      # that doesn't play nicely with our configs.
      action :create do
        systemd_unit "#{new_resource.service_name}.service" do
          content(
            Unit: {
              Description: 'The Nginx web server',
              Documentation: 'http://nginx.org/en/docs/',
              After: 'network-online.target remote-fs.target nss-lookup.target',
              Wants: 'network-online.target'
            },
            Service: {
              Type: 'forking',
              LimitNOFILE: new_resource.file_limit,
              PIDFile: "/run/#{new_resource.service_name}.pid",
              ExecStart: "/usr/sbin/nginx -c #{new_resource.config_file}",
              ExecReload: '/bin/kill -s HUP $MAINPID',
              ExecStop: '/bin/kill -s TERM $MAINPID'
            },
            Install: {
              WantedBy: 'multi-user.target'
            }
          )
          action :create
        end
      end

      # Delete the Systemd unit file from the :create action.
      action :remove do
        systemd_unit("#{new_resource.service_name}.service") { action :delete }
      end
    end
  end
end
