# frozen_string_literal: true

#
# Cookbook:: snu_nginx
# Library:: resource/snu_nginx_site
#
# Copyright:: 2019, Tyler Technologies
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

require_relative 'snu_nginx_config_base'

class Chef
  class Resource
    # A custom resource for managing Nginx site definitions.
    class SnuNginxSite < SnuNginxConfigBase
      provides :snu_nginx_site

      default_action %i[create enable]

      # The name of this site will be used to construct its config file path.
      property :site_name, String, name_property: true

      # Create the sites-available file.
      action :create do
        template ::File.join(new_resource.dir,
                             new_resource.service_name,
                             'sites-available',
                             new_resource.site_name) do
          owner 'root'
          group 'root'
          mode '0644'
          source new_resource.template
          cookbook new_resource.cookbook
          variables new_resource.variables
        end
      end

      # Delete the sites-available file.
      action :remove do
        file ::File.join(new_resource.dir,
                         new_resource.service_name,
                         'sites-available',
                         new_resource.site_name) do
          action :delete
        end
      end

      # Put a link to sites-available in sites-enabled.
      action :enable do
        link ::File.join(new_resource.dir,
                         new_resource.service_name,
                         'sites-enabled',
                         new_resource.site_name) do
          to ::File.join(new_resource.dir,
                         new_resource.service_name,
                         'sites-available',
                         new_resource.site_name)
          notifies :reload, "snu_nginx_service[#{new_resource.service_name}]"
        end
      end

      # Delete the link from sites-enabled.
      action :disable do
        link ::File.join(new_resource.dir,
                         new_resource.service_name,
                         'sites-enabled',
                         new_resource.site_name) do
          action :delete
          notifies :reload, "snu_nginx_service[#{new_resource.service_name}]"
        end
      end
    end
  end
end
